@@ -11,6 +11,12 @@
 
 #include "ui_dlgaccessibilitybase.h"
 
+#include "settings.h"
+
+#ifdef HAVE_SPEECH
+#include <QtTextToSpeech>
+#endif
+
 DlgAccessibility::DlgAccessibility( QWidget * parent )
     : QWidget( parent ), m_selected( 0 )
 {
@@ -28,6 +34,17 @@ DlgAccessibility::DlgAccessibility( QWidget * parent )
         page->hide();
     m_color_pages[ m_selected ]->show();
 
+#ifdef HAVE_SPEECH
+    // Populate tts engines
+    const QStringList engines = QTextToSpeech::availableEngines();
+    for (const QString &engine: engines) {
+        m_dlg->kcfg_ttsEngine->addItem (engine);
+    }
+    m_dlg->kcfg_ttsEngine->setProperty("kcfg_property", QByteArray("currentText"));
+#else
+    m_dlg->speechBox->hide();
+#endif
+
     connect(m_dlg->kcfg_RenderMode, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &DlgAccessibility::slotColorMode);
 }
 
