@@ -11,8 +11,8 @@
 #include "annotations_p.h"
 
 // qt/kde includes
-#include <QtWidgets/QApplication>
-#include <QtGui/QColor>
+#include <QApplication>
+#include <QColor>
 
 // DBL_MAX
 #include <float.h>
@@ -750,7 +750,7 @@ void Annotation::store( QDomNode & annNode, QDomDocument & document ) const
     if ( d->m_flags ) // Strip internal flags
         e.setAttribute( QStringLiteral("flags"), d->m_flags & ~(External | ExternallyDrawn | BeingMoved | BeingResized ) );
     if ( d->m_style.color().isValid() )
-        e.setAttribute( QStringLiteral("color"), d->m_style.color().name() );
+        e.setAttribute( QStringLiteral("color"), d->m_style.color().name( QColor::HexArgb ) );
     if ( d->m_style.opacity() != 1.0 )
         e.setAttribute( QStringLiteral("opacity"), QString::number( d->m_style.opacity() ) );
 
@@ -1028,6 +1028,7 @@ class Okular::TextAnnotationPrivate : public Okular::AnnotationPrivate
         TextAnnotation::TextType m_textType;
         QString m_textIcon;
         QFont m_textFont;
+        QColor m_textColor;
         int m_inplaceAlign;
         NormalizedPoint m_inplaceCallout[3];
         NormalizedPoint m_transformedInplaceCallout[3];
@@ -1087,6 +1088,18 @@ QFont TextAnnotation::textFont() const
     return d->m_textFont;
 }
 
+void TextAnnotation::setTextColor( const QColor &color )
+{
+	Q_D( TextAnnotation );
+	d->m_textColor = color;
+}
+
+QColor TextAnnotation::textColor() const
+{
+	Q_D( const TextAnnotation );
+	return d->m_textColor;
+}
+
 void TextAnnotation::setInplaceAlignment( int alignment )
 {
     Q_D( TextAnnotation );
@@ -1160,6 +1173,8 @@ void TextAnnotation::store( QDomNode & node, QDomDocument & document ) const
         textElement.setAttribute( QStringLiteral("icon"), d->m_textIcon );
     if ( d->m_textFont != QApplication::font() )
         textElement.setAttribute( QStringLiteral("font"), d->m_textFont.toString() );
+    if ( d->m_textColor.isValid() )
+        textElement.setAttribute( QStringLiteral("fontColor"), d->m_textColor.name() );
     if ( d->m_inplaceAlign )
         textElement.setAttribute( QStringLiteral("align"), d->m_inplaceAlign );
     if ( d->m_inplaceIntent != Unknown )
@@ -1246,6 +1261,8 @@ void TextAnnotationPrivate::setAnnotationProperties( const QDomNode& node )
             m_textIcon = e.attribute( QStringLiteral("icon") );
         if ( e.hasAttribute( QStringLiteral("font") ) )
             m_textFont.fromString( e.attribute( QStringLiteral("font") ) );
+        if ( e.hasAttribute( QStringLiteral("fontColor") ) )
+            m_textColor = QColor( e.attribute( QStringLiteral("fontColor") ) );
         if ( e.hasAttribute( QStringLiteral("align") ) )
             m_inplaceAlign = e.attribute( QStringLiteral("align") ).toInt();
         if ( e.hasAttribute( QStringLiteral("intent") ) )
