@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007 by Pino Toscano <pino@kde.org>                     *
+ *   Copyright (C) 2014 by Frederik Gladhorn <gladhorn@kde.org>            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -7,9 +8,11 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#ifndef _OKUAR_DEBUG_P_H_
-#define _OKUAR_DEBUG_P_H_
+#ifndef OKULAR_DEBUG_P_H
+#define OKULAR_DEBUG_P_H
 
-#define OkularDebug 4700
+#include <qloggingcategory.h>
+
+Q_DECLARE_LOGGING_CATEGORY(OkularCoreDebug)
 
 #endif
