@@ -668,6 +668,34 @@ class OKULARCORE_EXPORT Document : public QObject
          */
         void processAction( const Action *action );
 
+        /**
+         * Processes the given format @p action on @p field.
+         *
+         * @since 1.9
+         */
+        void processFormatAction( const Action *action, Okular::FormFieldText *field );
+
+        /**
+         * Processes the given keystroke @p action on @p field.
+         *
+         * @since 1.9
+         */
+        void processKeystrokeAction( const Action *action, Okular::FormFieldText *field, bool &returnCode );
+
+        /**
+         * Processes the given focus action on the field.
+         *
+         * @since 1.9
+         */
+        void processFocusAction( const Action *action, Okular::FormField *field );
+        
+        /**
+         * Processes the given keystroke @p action on @p field.
+         *
+         * @since 1.9
+         */
+        void processValidateAction( const Action *action, Okular::FormFieldText *field, bool &returnCode );
+        
         /**
          * Returns a list of the bookmarked.pages
          */
