@@ -12,8 +12,10 @@
 #define _OKULAR_DOCUMENT_P_H_
 
 #include "document.h"
+#include "script/event_p.h"
 
 #include "synctex/synctex_parser.h"
+#include <memory>
 
 // qt/kde/system includes
 #include <QHash>
@@ -41,6 +43,7 @@ struct ArchiveData;
 struct RunningSearch;
 
 namespace Okular {
+class ScriptAction;
 class ConfigInterface;
 class PageController;
 class SaveInterface;
@@ -191,6 +194,13 @@ class DocumentPrivate
 
         void doProcessSearchMatch( RegularAreaRect *match, RunningSearch *search, QSet< int > *pagesToNotify, int currentPage, int searchID, bool moveViewport, const QColor & color );
 
+        /**
+         * Executes a JavaScript script from the setInterval function.
+         *
+         * @since 1.9
+        */
+        void executeScript( const QString &function );
+
         // generators stuff
         /**
          * This method is used by the generators to signal the finish of
@@ -220,6 +230,17 @@ class DocumentPrivate
 
         void clearAndWaitForRequests();
 
+
+        /*
+         * Executes a ScriptAction with the event passed as parameter.
+         */ 
+        void executeScriptEvent( const std::shared_ptr< Event > &event, const Okular::ScriptAction * linkscript );
+
+        /*
+         * Find the corresponding page number for the form field passed as parameter.
+         */
+        int findFieldPageNumber( Okular::FormField *field );
+
         // member variables
         Document *m_parent;
         QPointer<QWidget> m_widget;
