@@ -70,6 +70,15 @@ void FormField::setVisible( bool )
 {
 }
 
+bool FormField::isPrintable() const
+{
+    return true;
+}
+
+void FormField::setPrintable( bool )
+{
+}
+
 Action* FormField::activationAction() const
 {
     Q_D( const FormField );
@@ -129,7 +138,7 @@ class Okular::FormFieldButtonPrivate : public Okular::FormFieldPrivate
         QString value() const override
         {
             Q_Q( const FormFieldButton );
-            return qVariantFromValue<bool>( q->state() ).toString();
+            return QVariant::fromValue<bool>( q->state() ).toString();
         }
 };
 
@@ -147,6 +156,10 @@ void FormFieldButton::setState( bool )
 {
 }
 
+void FormFieldButton::setIcon( Okular::FormField * )
+{
+}
+
 
 class Okular::FormFieldTextPrivate : public Okular::FormFieldPrivate
 {
@@ -210,7 +223,6 @@ bool FormFieldText::canBeSpellChecked() const
     return false;
 }
 
-
 class Okular::FormFieldChoicePrivate : public Okular::FormFieldPrivate
 {
     public:
