@@ -21,25 +21,24 @@
 #include "global.h"
 #include "pagesize.h"
 
-#include <QtCore/QList>
-#include <QtCore/QObject>
-#include <QtCore/QSharedDataPointer>
-#include <QtCore/QSizeF>
-#include <QtCore/QString>
-#include <QtCore/QVariant>
-#include <QtCore/QVector>
+#include <QList>
+#include <QObject>
+#include <QSharedDataPointer>
+#include <QSizeF>
+#include <QString>
+#include <QVariant>
+#include <QVector>
 
 #include <QMimeType>
 #include <kpluginfactory.h>
 
 #define OKULAR_EXPORT_PLUGIN(classname, json ) \
     static_assert(json[0] != '\0', "arg2 must be a string literal"); \
-    K_PLUGIN_FACTORY_WITH_JSON(classname ## Factory, json, registerPlugin<classname >();)
+    K_PLUGIN_CLASS_WITH_JSON(classname, json)
 
 class QByteArray;
 class QMutex;
 class QPrinter;
-class QPrintDialog;
 class QIcon;
 
 namespace Okular {
@@ -60,10 +59,9 @@ class TextPage;
 class TextRequest;
 class TextRequestPrivate;
 class NormalizedRect;
-class SourceReference;
 
 /* Note: on contents generation and asynchronous queries.
- * Many observers may want to request data syncronously or asynchronously.
+ * Many observers may want to request data synchronously or asynchronously.
  * - Sync requests. These should be done in-place.
  * - Async request must be done in real background. That usually means a
  *   thread, such as QThread derived classes.
@@ -205,7 +203,7 @@ class OKULARCORE_EXPORT Generator : public QObject
          */
         enum GeneratorFeature
         {
-            Threaded,
+            Threaded,          ///< Whether the Generator supports asynchronous generation of pictures or text pages
             TextExtraction,    ///< Whether the Generator can extract text from the document in the form of TextPage's
             ReadRawData,       ///< Whether the Generator can read a document directly from its raw data.
             FontInfo,          ///< Whether the Generator can provide information about the fonts used in the document
@@ -221,7 +219,7 @@ class OKULARCORE_EXPORT Generator : public QObject
         /**
          * Creates a new generator.
          */
-        Generator(QObject* parent = nullptr, const QVariantList& args = QVariantList());
+        explicit Generator(QObject* parent = nullptr, const QVariantList& args = QVariantList());
 
         /**
          * Destroys the generator.
@@ -348,7 +346,7 @@ class OKULARCORE_EXPORT Generator : public QObject
         virtual const DocumentSynopsis * generateDocumentSynopsis();
 
         /**
-         * Returns the 'list of embedded fonts' object of the specified \page
+         * Returns the 'list of embedded fonts' object of the specified \p page
          * of the document.
          *
          * \param page a page of the document, starting from 0 - -1 indicates all
@@ -378,8 +376,8 @@ class OKULARCORE_EXPORT Generator : public QObject
         virtual PageSizeMetric pagesSizeMetric() const;
 
         /**
-         * This method returns whether given @p action (@ref Permission) is
-         * allowed in this document.
+         * Returns whether the given @p action is allowed in the document.
+         * @see @ref Okular::Permission
          */
         virtual bool isAllowed( Permission action ) const;
 
@@ -781,7 +779,7 @@ class OKULARCORE_EXPORT TextRequest
         /**
          * Creates a new text request.
          */
-        TextRequest( Page *page );
+        explicit TextRequest( Page *page );
 
         TextRequest();
 
