@@ -56,14 +56,18 @@ class Event
             ExternalExec,    /// < Not implemented.
             FieldBlur,       /// < Not implemented.
             FieldCalculate,  /// < This event is defined in a field re-calculation.
-            FieldFocus,      /// < Not implemented.
-            FieldFormat,     /// < Not implemented.
-            FieldKeystroke,  /// < Not implemented.
+            FieldFocus,      /// < This event is defined when the field gains or loses focus.
+            FieldFormat,     /// < When a format action is executed
+            FieldKeystroke,  /// < Checks if the entered value is valid.
             FieldMouseDown,  /// < Not implemented.
             FieldMouseEnter, /// < Not implemented.
             FieldMouseExit,  /// < Not implemented.
             FieldMouseUp,    /// < Not implemented.
-            FieldValidate,   /// < Not implemented.
+            /* Validates the field after every change is committed
+             * (clicked outside or tabbed to another field).
+             * The enter event is not handled
+             */
+            FieldValidate,
             LinkMouseUp,     /// < Not implemented.
             MenuExec,        /// < Not implemented.
             PageOpen,        /// < Not implemented.
@@ -97,11 +101,27 @@ class Event
         QVariant value() const;
         void setValue(const QVariant &val);
 
+        bool returnCode() const;
+        void setReturnCode(bool returnCode);
+
+        // Checks if the shift key was down when creating the event.
+        bool shiftModifier() const;
+        void setShiftModifier(bool shiftModifier);
+
         static std::shared_ptr<Event> createFormCalculateEvent( FormField *target,
                                                                 Page *targetPage,
                                                                 FormField *source = nullptr,
                                                                 Page *sourcePage = nullptr,
                                                                 const QString &targetName = QString() );
+        static std::shared_ptr<Event> createFormatEvent( FormField *target, Page *targetPage,
+                                                         const QString &targetName = QString() );
+        static std::shared_ptr<Event> createKeystrokeEvent( FormField *target, Page *targetPage );
+        static std::shared_ptr<Event> createFormFocusEvent( FormField *target,
+                                                            Page *targetPage,
+                                                            const QString &targetName = QString() );
+        static std::shared_ptr<Event> createFormValidateEvent( FormField *target,
+                                                               Page *targetPage,
+                                                               const QString &targetName = QString() );
     private:
         class Private;
         std::shared_ptr<Private> d;
