@@ -24,10 +24,12 @@
 #include "kjs_app_p.h"
 #include "kjs_console_p.h"
 #include "kjs_data_p.h"
+#include "kjs_display_p.h"
 #include "kjs_document_p.h"
 #include "kjs_event_p.h"
 #include "kjs_field_p.h"
 #include "kjs_fullscreen_p.h"
+#include "kjs_ocg_p.h"
 #include "kjs_spell_p.h"
 #include "kjs_util_p.h"
 
@@ -64,15 +66,19 @@ void ExecutorKJSPrivate::initTypes()
     JSFullscreen::initType( ctx );
     JSConsole::initType( ctx );
     JSData::initType( ctx );
+    JSDisplay::initType( ctx );
     JSDocument::initType( ctx );
     JSEvent::initType( ctx );
     JSField::initType( ctx );
+    JSOCG::initType( ctx );
     JSSpell::initType( ctx );
     JSUtil::initType( ctx );
 
     m_docObject.setProperty( ctx, QStringLiteral("app"), JSApp::object( ctx, m_doc ) );
     m_docObject.setProperty( ctx, QStringLiteral("console"), JSConsole::object( ctx ) );
     m_docObject.setProperty( ctx, QStringLiteral("Doc"), m_docObject );
+    m_docObject.setProperty( ctx, QStringLiteral("display"), JSDisplay::object( ctx ) );
+    m_docObject.setProperty( ctx, QStringLiteral("OCG"), JSOCG::object( ctx ) );
     m_docObject.setProperty( ctx, QStringLiteral("spell"), JSSpell::object( ctx ) );
     m_docObject.setProperty( ctx, QStringLiteral("util"), JSUtil::object( ctx ) );
 }
@@ -84,6 +90,9 @@ ExecutorKJS::ExecutorKJS( DocumentPrivate *doc )
 
 ExecutorKJS::~ExecutorKJS()
 {
+    JSField::clearCachedFields();
+    JSApp::clearCachedFields();
+    JSOCG::clearCachedFields();
     delete d;
 }
 
@@ -106,6 +115,7 @@ void ExecutorKJS::execute( const QString &script, Event *event )
 
     KJSResult result = d->m_interpreter->evaluate( QStringLiteral("okular.js"), 1,
                                                    script, &d->m_docObject );
+    
     if ( result.isException() || ctx->hasException() )
     {
         qCDebug(OkularCoreDebug) << "JS exception" << result.errorMessage();
@@ -120,5 +130,4 @@ void ExecutorKJS::execute( const QString &script, Event *event )
                                      << event->type() << "value:" << event->value();
         }
     }
-    JSField::clearCachedFields();
 }
