@@ -13,6 +13,7 @@
 
 class KJSContext;
 class KJSObject;
+class QTimer;
 
 namespace Okular {
 
@@ -23,6 +24,8 @@ class JSApp
     public:
         static void initType( KJSContext *ctx );
         static KJSObject object( KJSContext *ctx, DocumentPrivate *doc );
+        static KJSObject wrapTimer( KJSContext *ctx, QTimer *timer );
+        static void clearCachedFields();
 };
 
 }
