@@ -15,7 +15,6 @@
 class KArchiveDirectory;
 class KArchive;
 class QImage;
-class QSize;
 class Unrar;
 class Directory;
 
@@ -48,7 +47,7 @@ class Document
         Directory *mDirectory;
         Unrar *mUnrar;
         KArchive *mArchive;
-        KArchiveDirectory *mArchiveDir;
+        const KArchiveDirectory *mArchiveDir;
         QString mLastErrorString;
         QStringList mEntries;
 };
