@@ -595,12 +595,12 @@ void dviRenderer::prescan_parseSpecials(char *cp, quint8 *)
 void dviRenderer::prescan_setChar(unsigned int ch)
 {
   TeXFontDefinition *fontp = currinf.fontp;
-  if (fontp == NULL)
+  if (fontp == nullptr)
     return;
 
   if (currinf.set_char_p == &dviRenderer::set_char) {
     glyph *g = ((TeXFont *)(currinf.fontp->font))->getGlyph(ch, true, globalColor);
-    if (g == NULL)
+    if (g == nullptr)
       return;
     currinf.data.dvi_h += (int)(currinf.fontp->scaled_size_in_DVI_units * dviFile->getCmPerDVIunit() *
                                 (1200.0 / 2.54)/16.0 * g->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
@@ -609,7 +609,7 @@ void dviRenderer::prescan_setChar(unsigned int ch)
 
   if (currinf.set_char_p == &dviRenderer::set_vf_char) {
     macro *m = &currinf.fontp->macrotable[ch];
-    if (m->pos == NULL)
+    if (m->pos == nullptr)
       return;
     currinf.data.dvi_h += (int)(currinf.fontp->scaled_size_in_DVI_units * dviFile->getCmPerDVIunit() *
                                 (1200.0 / 2.54)/16.0 * m->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
@@ -633,7 +633,7 @@ void dviRenderer::prescan(parseSpecials specialParser)
 
   stack.clear();
 
-  currinf.fontp        = NULL;
+  currinf.fontp        = nullptr;
   currinf.set_char_p   = &dviRenderer::set_no_char;
 
   for (;;) {
@@ -646,7 +646,7 @@ void dviRenderer::prescan(parseSpecials specialParser)
 
     if (FNTNUM0 <= ch && ch <= (unsigned char) (FNTNUM0 + 63)) {
       currinf.fontp = currinf.fonttable->value(ch - FNTNUM0);
-      if (currinf.fontp == NULL) {
+      if (currinf.fontp == nullptr) {
         errorMsg = i18n("The DVI code referred to font #%1, which was not previously defined.", ch - FNTNUM0);
         return;
       }
@@ -769,7 +769,7 @@ void dviRenderer::prescan(parseSpecials specialParser)
     case FNT3:
     case FNT4:
       currinf.fontp = currinf.fonttable->value(readUINT(ch - FNT1 + 1));
-      if (currinf.fontp == NULL)
+      if (currinf.fontp == nullptr)
         return;
       currinf.set_char_p = currinf.fontp->set_char_p;
       break;
