@@ -9,8 +9,8 @@
 
 #include "generator_fax.h"
 
-#include <QtGui/QPainter>
-#include <QtPrintSupport/QPrinter>
+#include <QPainter>
+#include <QPrinter>
 
 #include <KAboutData>
 #include <KLocalizedString>
