@@ -12,7 +12,7 @@
 
 #include <core/generator.h>
 
-#include <QtGui/QImage>
+#include <QImage>
 
 #include "faxdocument.h"
 
@@ -25,15 +25,15 @@ class FaxGenerator : public Okular::Generator
         FaxGenerator( QObject *parent, const QVariantList &args );
         virtual ~FaxGenerator();
 
-        bool loadDocument( const QString & fileName, QVector<Okular::Page*> & pagesVector ) Q_DECL_OVERRIDE;
+        bool loadDocument( const QString & fileName, QVector<Okular::Page*> & pagesVector ) override;
 
-        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const Q_DECL_OVERRIDE;
+        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const override;
 
-        bool print( QPrinter& printer ) Q_DECL_OVERRIDE;
+        bool print( QPrinter& printer ) override;
 
     protected:
-        bool doCloseDocument() Q_DECL_OVERRIDE;
-        QImage image( Okular::PixmapRequest * request ) Q_DECL_OVERRIDE;
+        bool doCloseDocument() override;
+        QImage image( Okular::PixmapRequest * request ) override;
 
     private:
         QImage m_img;
