@@ -9,16 +9,16 @@
 
 #include "converter.h"
 
-#include <QtCore/QQueue>
-#include <QtCore/QUrl>
-#include <QtGui/QTextCursor>
-#include <QtGui/QTextDocument>
-#include <QtGui/QTextFrame>
-#include <QtGui/QTextList>
-#include <QtGui/QTextTableCell>
-#include <QtXml/QDomElement>
-#include <QtXml/QDomText>
-#include <QtXml/QXmlSimpleReader>
+#include <QQueue>
+#include <QUrl>
+#include <QTextCursor>
+#include <QTextDocument>
+#include <QTextFrame>
+#include <QTextList>
+#include <QTextTableCell>
+#include <QDomElement>
+#include <QDomText>
+#include <QXmlSimpleReader>
 
 #include <core/action.h>
 #include <core/annotations.h>
@@ -63,8 +63,8 @@ QTextCharFormat Style::textFormat() const
 }
 
 Converter::Converter()
-  : mTextDocument( 0 ), mCursor( 0 ),
-    mStyleInformation( 0 )
+  : mTextDocument( nullptr ), mCursor( nullptr ),
+    mStyleInformation( nullptr )
 {
 }
 
@@ -177,7 +177,7 @@ Okular::Document::OpenResult Converter::convertWithPassword( const QString &file
 
   delete mCursor;
   delete mStyleInformation;
-  mStyleInformation = 0;
+  mStyleInformation = nullptr;
 
   setDocument( mTextDocument );
   return Okular::Document::OpenSuccess;
