@@ -11,6 +11,7 @@
 #define _OKULAR_GENERATOR_PDF_FORMFIELDS_H_
 
 #include <poppler-form.h>
+#include <config-okular-poppler.h>
 #include "core/form.h"
 
 class PopplerFormFieldButton : public Okular::FormFieldButton
@@ -24,10 +25,13 @@ class PopplerFormFieldButton : public Okular::FormFieldButton
         int id() const override;
         QString name() const override;
         QString uiName() const override;
+        QString fullyQualifiedName() const override;
         bool isReadOnly() const override;
         void setReadOnly( bool value ) override;
         bool isVisible() const override;
         void setVisible( bool value ) override;
+        bool isPrintable() const override;
+        void setPrintable( bool value ) override;
 
         // inherited from Okular::FormFieldButton
         ButtonType buttonType() const override;
@@ -35,6 +39,15 @@ class PopplerFormFieldButton : public Okular::FormFieldButton
         bool state() const override;
         void setState( bool state ) override;
         QList< int > siblings() const override;
+        void setIcon( Okular::FormField *field ) override;
+#ifdef HAVE_POPPLER_0_79
+        /*
+         * Supported only in newer versions of Poppler library.
+         *
+         * @since 1.9
+        */
+        Poppler::FormFieldIcon icon() const;
+#endif
 
     private:
         Poppler::FormFieldButton * m_field;
@@ -54,15 +67,19 @@ class PopplerFormFieldText : public Okular::FormFieldText
         int id() const override;
         QString name() const override;
         QString uiName() const override;
+        QString fullyQualifiedName() const override;
         bool isReadOnly() const override;
         void setReadOnly( bool value ) override;
         bool isVisible() const override;
         void setVisible( bool value ) override;
+        bool isPrintable() const override;
+        void setPrintable( bool value ) override;
 
         // inherited from Okular::FormFieldText
         Okular::FormFieldText::TextType textType() const override;
         QString text() const override;
         void setText( const QString& text ) override;
+        void setAppearanceText( const QString& text ) override;
         bool isPassword() const override;
         bool isRichText() const override;
         int maximumLength() const override;
@@ -87,10 +104,13 @@ class PopplerFormFieldChoice : public Okular::FormFieldChoice
         int id() const override;
         QString name() const override;
         QString uiName() const override;
+        QString fullyQualifiedName() const override;
         bool isReadOnly() const override;
         void setReadOnly( bool value ) override;
         bool isVisible() const override;
         void setVisible( bool value ) override;
+        bool isPrintable() const override;
+        void setPrintable( bool value ) override;
 
         // inherited from Okular::FormFieldChoice
         ChoiceType choiceType() const override;
@@ -122,6 +142,7 @@ class PopplerFormFieldSignature : public Okular::FormFieldSignature
         int id() const override;
         QString name() const override;
         QString uiName() const override;
+        QString fullyQualifiedName() const override;
         bool isReadOnly() const override;
         bool isVisible() const override;
 
