@@ -7,18 +7,24 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#ifndef _TXT_DOCUMENT_H_
+#define _TXT_DOCUMENT_H_
 
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
 
 namespace Txt
 {
     class Document : public QTextDocument
     {
+        Q_OBJECT
+
         public:
-            Document( const QString &fileName );
+            explicit Document( const QString &fileName );
             ~Document();
 
         private:
             QString toUnicode( const QByteArray &array );
     };
 }
+
+#endif
