@@ -11,28 +11,14 @@
 #include "generator_txt.h"
 #include "converter.h"
 
-#include <kaboutdata.h>
+#include <KAboutData>
+#include <klocalizedstring.h>
 #include <KConfigDialog>
 
-static KAboutData createAboutData()
-{
-    KAboutData aboutData(
-         "okular_txt",
-         "okular_txt",
-         ki18n( "Txt Backend" ),
-         "0.1",
-         ki18n( "Txt backend." ),
-         KAboutData::License_GPL,
-         ki18n( "© 2013 Azat Khuzhin" )
-    );
-    aboutData.addAuthor( ki18n( "Azat Khuzhin" ), KLocalizedString(), "a3at.mail@gmail.com" );
-    return aboutData;
-}
+OKULAR_EXPORT_PLUGIN(TxtGenerator, "libokularGenerator_txt.json")
 
-OKULAR_EXPORT_PLUGIN( TxtGenerator, createAboutData() )
-
-TxtGenerator::TxtGenerator( QObject *parent, const QVariantList &args )
-    : Okular::TextDocumentGenerator( new Txt::Converter, "okular_txt_generator_settings", parent, args )
+TxtGenerator::TxtGenerator(QObject *parent, const QVariantList &args)
+    : Okular::TextDocumentGenerator(new Txt::Converter, QStringLiteral("okular_txt_generator_settings") , parent, args)
 {
 }
 
@@ -40,5 +26,7 @@ void TxtGenerator::addPages( KConfigDialog* dlg )
 {
     Okular::TextDocumentSettingsWidget *widget = new Okular::TextDocumentSettingsWidget();
 
-    dlg->addPage( widget, generalSettings(), i18n("Txt"), "text-plain", i18n("Txt Backend Configuration") );
+    dlg->addPage( widget, generalSettings(), i18n("Txt"), QStringLiteral("text-plain"), i18n("Txt Backend Configuration") );
 }
+
+#include "generator_txt.moc"
