@@ -47,12 +47,9 @@ class QPrinter;
 class QMenu;
 
 class KConfigDialog;
-class KConfigGroup;
 class KDirWatch;
 class KToggleAction;
 class KToggleFullScreenAction;
-class KSelectAction;
-class KAboutData;
 class QTemporaryFile;
 class QAction;
 class QJsonObject;
@@ -170,6 +167,7 @@ class OKULARPART_EXPORT Part : public KParts::ReadWritePart, public Okular::Docu
         Q_SCRIPTABLE Q_NOREPLY void enableStartWithPrint();
         Q_SCRIPTABLE Q_NOREPLY void enableExitAfterPrint();
         Q_SCRIPTABLE Q_NOREPLY void enableStartWithFind(const QString &text);
+        Q_SCRIPTABLE void slotOpenContainingFolder();
 
     Q_SIGNALS:
         void enablePrintAction(bool enable);
@@ -360,6 +358,7 @@ class OKULARPART_EXPORT Part : public KParts::ReadWritePart, public Okular::Docu
         QAction *m_nextBookmark;
         QAction *m_copy;
         QAction *m_selectAll;
+        QAction *m_selectCurrentPage;
         QAction *m_find;
         QAction *m_findNext;
         QAction *m_findPrev;
@@ -376,6 +375,7 @@ class OKULARPART_EXPORT Part : public KParts::ReadWritePart, public Okular::Docu
         QAction *m_share;
 #endif
         QAction *m_showPresentation;
+        QAction *m_openContainingFolder;
         KToggleAction* m_showMenuBarAction;
         KToggleAction* m_showLeftPanel;
         KToggleAction* m_showBottomBar;
