@@ -58,7 +58,7 @@ QUrl urlFromArg( const QString& _arg, FileExistFunc exist_func, const QString& p
     if ( !pageArg.isEmpty() )
     {
       url.setFragment( pageArg );
-    }
+    }  
     return url;
 }
 
@@ -70,19 +70,21 @@ QString serializeOptions(const QCommandLineParser &args)
     const bool unique = args.isSet(QStringLiteral("unique")) && args.positionalArguments().count() <= 1;
     const bool noRaise = args.isSet(QStringLiteral("noraise"));
     const QString page = args.value(QStringLiteral("page"));
+    const QString find = args.value(QStringLiteral("find"));
 
-    return serializeOptions(startInPresentation, showPrintDialog, showPrintDialogAndExit, unique, noRaise, page);
+    return serializeOptions(startInPresentation, showPrintDialog, showPrintDialogAndExit, unique, noRaise, page, find);
 }
 
-QString serializeOptions(bool startInPresentation, bool showPrintDialog, bool showPrintDialogAndExit, bool unique, bool noRaise, const QString &page)
+QString serializeOptions(bool startInPresentation, bool showPrintDialog, bool showPrintDialogAndExit, bool unique, bool noRaise, const QString &page, const QString &find)
 {
-    return QStringLiteral("%1:%2:%3:%4:%5:%6").arg(startInPresentation).arg(showPrintDialog).arg(showPrintDialogAndExit).arg(unique).arg(noRaise).arg(page);
+    return QStringLiteral("%1:%2:%3:%4:%5:%6:%7").arg(startInPresentation).arg(showPrintDialog).arg(showPrintDialogAndExit).arg(unique).arg(noRaise).arg(page).arg(QString(find.toLatin1().toBase64()));
 }
 
-bool unserializeOptions(const QString &serializedOptions, bool *presentation, bool *print, bool *print_and_exit, bool *unique, bool *noraise, QString *page)
+bool unserializeOptions(const QString &serializedOptions, bool *presentation, bool *print, bool *print_and_exit, bool *unique, bool *noraise, QString *page, QString *find)
 {
     const QStringList args = serializedOptions.split(QStringLiteral(":"));
-    if (args.count() == 6)
+
+    if (args.count() == 7)
     {
         *presentation = args[0] == QLatin1String("1");
         *print = args[1] == QLatin1String("1");
@@ -90,6 +92,7 @@ bool unserializeOptions(const QString &serializedOptions, bool *presentation, bo
         *unique = args[3] == QLatin1String("1");
         *noraise = args[4] == QLatin1String("1");
         *page = args[5];
+        *find = args[6];
         return true;
     }
     return false;
@@ -99,43 +102,51 @@ bool startInPresentation(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &result, &dummy, &dummy, &dummy, &dummy, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &result, &dummy, &dummy, &dummy, &dummy, &dummyString, &dummyString) && result;
 }
 
 bool showPrintDialog(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &result, &dummy, &dummy, &dummy, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &result, &dummy, &dummy, &dummy, &dummyString, &dummyString) && result;
 }
 
 bool showPrintDialogAndExit(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &dummy, &result, &dummy, &dummy, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &dummy, &result, &dummy, &dummy, &dummyString, &dummyString) && result;
 }
 
 bool unique(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &result, &dummy, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &result, &dummy, &dummyString, &dummyString) && result;
 }
 
 bool noRaise(const QString &serializedOptions)
 {
     bool result, dummy;
     QString dummyString;
-    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &result, &dummyString) && result;
+    return unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &result, &dummyString, &dummyString) && result;
 }
 
 QString page(const QString &serializedOptions)
 {
-    QString result;
+    QString result, dummyString;
     bool dummy;
-    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &result);
+    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &result, &dummyString);
     return result;
 }
 
+QString find(const QString &serializedOptions)
+{
+    QString result, dummyString;
+    bool dummy;
+    unserializeOptions(serializedOptions, &dummy, &dummy, &dummy, &dummy, &dummy, &dummyString, &result);
+    return QString(QByteArray::fromBase64(result.toLatin1()));
+}
+
 }
