@@ -98,7 +98,7 @@ class FileItem : public QTreeWidgetItem
             setFlags( Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable );
             const QString fileString = document->bookmarkManager()->titleForUrl( url );
             setText( 0, fileString );
-            setData( 0, UrlRole, qVariantFromValue( url ) );
+            setData( 0, UrlRole, QVariant::fromValue( url ) );
         }
 
         QVariant data( int column, int role ) const override
@@ -119,7 +119,7 @@ BookmarkList::BookmarkList( Okular::Document *document, QWidget *parent )
     : QWidget( parent ), m_document( document ), m_currentDocumentItem( nullptr )
 {
     QVBoxLayout *mainlay = new QVBoxLayout( this );
-    mainlay->setMargin( 0 );
+    mainlay->setContentsMargins( 0, 0, 0, 0 );
     mainlay->setSpacing( 6 );
 
     m_searchLine = new KTreeWidgetSearchLine( this );
