@@ -28,6 +28,7 @@
 #include <QPainter>
 
 // local includes
+#include "core/action.h"
 #include "core/form.h"
 #include "core/document.h"
 #include "debug_ui.h"
@@ -89,6 +90,30 @@ void FormWidgetsController::signalAction( Okular::Action *a )
     emit action( a );
 }
 
+void FormWidgetsController::processScriptAction( Okular::Action *a, Okular::FormField * field, Okular::Annotation::AdditionalActionType type )
+{
+    // If it's not a Action Script or if the field is not a FormText, handle it normally
+    if( a->actionType() != Okular::Action::Script || field->type() != Okular::FormField::FormText )
+    {
+        emit action( a );
+        return;
+    }
+    switch( type )
+    {
+        // These cases are to be handled by the FormField text, so we let it happen.
+        case Okular::Annotation::FocusIn:
+        case Okular::Annotation::FocusOut:
+            return;  
+        case Okular::Annotation::PageOpening:
+        case Okular::Annotation::PageClosing:
+        case Okular::Annotation::CursorEntering:
+        case Okular::Annotation::CursorLeaving:
+        case Okular::Annotation::MousePressed:
+        case Okular::Annotation::MouseReleased:
+            emit action( a );
+    }
+}
+
 void FormWidgetsController::registerRadioButton( FormWidgetIface *fwButton, Okular::FormFieldButton *formButton )
 {
     if ( !fwButton )
@@ -106,12 +131,13 @@ void FormWidgetsController::registerRadioButton( FormWidgetIface *fwButton, Okul
     m_buttons.insert( id, button );
     for ( ; it != itEnd; ++it )
     {
-        const QList< int >::const_iterator idsIt = qFind( (*it).ids, id );
-        if ( idsIt != (*it).ids.constEnd() )
+        const RadioData &rd = *it;
+        const QList< int >::const_iterator idsIt = std::find( rd.ids.begin(), rd.ids.end(), id );
+        if ( idsIt != rd.ids.constEnd() )
         {
-            qCDebug(OkularUiDebug) << "Adding id" << id << "To group including" << (*it).ids;
-            (*it).group->addButton( button );
-            (*it).group->setId( button, id );
+            qCDebug(OkularUiDebug) << "Adding id" << id << "To group including" << rd.ids;
+            rd.group->addButton( button );
+            rd.group->setId( button, id );
             return;
         }
     }
@@ -375,7 +401,7 @@ void FormWidgetIface::slotRefresh( Okular::FormField * form )
     {
         return;
     }
-    setVisibility( form->isVisible() /*&& !form->isReadOnly()*/ );
+    setVisibility( form->isVisible() && m_controller->shouldFormWidgetBeShown( form ) );
 
     m_widget->setEnabled( !form->isReadOnly() );
 }
@@ -385,6 +411,12 @@ PushButtonEdit::PushButtonEdit( Okular::FormFieldButton * button, QWidget * pare
     : QPushButton( parent ), FormWidgetIface( this, button )
 {
     setText( button->caption() );
+    
+    if( button->caption().isEmpty() )
+    {
+        setFlat( true );
+    }
+    
     setVisible( button->isVisible() );
     setCursor( Qt::ArrowCursor );
 }
@@ -464,6 +496,7 @@ FormLineEdit::FormLineEdit( Okular::FormFieldText * text, QWidget * parent )
 
     m_prevCursorPos = cursorPosition();
     m_prevAnchorPos = cursorPosition();
+    m_editing = false;
 
     connect( this, &QLineEdit::textEdited, this, &FormLineEdit::slotChanged );
     connect( this, &QLineEdit::cursorPositionChanged, this, &FormLineEdit::slotChanged );
@@ -494,6 +527,33 @@ bool FormLineEdit::event( QEvent* e )
             return true;
         }
     }
+    else if ( e->type() == QEvent::FocusIn )
+    {
+        const auto fft = static_cast< Okular::FormFieldText * > ( m_ff );
+        setText( fft->text() );
+        m_editing = true;
+        if( const Okular::Action *action = m_ff->additionalAction( Okular::Annotation::FocusIn ) )
+            emit m_controller->focusAction( action, fft );
+        setFocus();
+    }
+    else if ( e->type() == QEvent::FocusOut )
+    {
+        // Don't worry about focus events from other sources than the user FocusEvent to edit the field
+        QFocusEvent *focusEvent = static_cast< QFocusEvent* >( e );
+        if( focusEvent->reason() == Qt::OtherFocusReason )
+            return true;
+        m_editing = false;
+        
+        if( const Okular::Action *action = m_ff->additionalAction( Okular::Annotation::FocusOut ) )
+        {
+            bool ok = false;
+            emit m_controller->validateAction( action, static_cast< Okular::FormFieldText * > ( m_ff ), ok );
+        }
+        if ( const Okular::Action *action = m_ff->additionalAction( Okular::FormField::FormatField ) )
+        {
+            emit m_controller->formatAction( action, static_cast< Okular::FormFieldText * > ( m_ff ) );
+        }
+    }
     return QLineEdit::event( e );
 }
 
@@ -530,6 +590,21 @@ void FormLineEdit::slotChanged()
     Okular::FormFieldText *form = static_cast<Okular::FormFieldText *>(m_ff);
     QString contents = text();
     int cursorPos = cursorPosition();
+
+    if( form->additionalAction( Okular::FormField::FieldModified ) && m_editing && !form->isReadOnly() )
+    {
+        bool ok = false;
+        QString oldInputText = form->text();
+        form->setText( text() );
+        emit m_controller->keystrokeAction( form->additionalAction( Okular::FormField::FieldModified ), form, ok );
+        form->setText( oldInputText );
+        if(!ok)
+        {
+            setText( oldInputText );
+            return;
+        }
+    }
+
     if ( contents != form->text() )
     {
         m_controller->formTextChangedByWidget( pageItem()->pageNumber(),
@@ -599,6 +674,7 @@ TextAreaEdit::TextAreaEdit( Okular::FormFieldText * text, QWidget * parent )
              this, &TextAreaEdit::slotUpdateUndoAndRedoInContextMenu );
     m_prevCursorPos = textCursor().position();
     m_prevAnchorPos = textCursor().anchor();
+    m_editing = false;
     setVisible( text->isVisible() );
 }
 
@@ -626,6 +702,20 @@ bool TextAreaEdit::event( QEvent* e )
             return true;
         }
     }
+    else if ( e->type() == QEvent::FocusIn )
+    {
+        const auto fft = static_cast< Okular::FormFieldText * > ( m_ff );
+        setText( fft->text() );
+        m_editing = true;
+    }
+    else if ( e->type() == QEvent::FocusOut )
+    {
+        m_editing = false;
+        if ( const Okular::Action *action = m_ff->additionalAction( Okular::FormField::FormatField ) )
+        {
+            emit m_controller->formatAction( action, static_cast< Okular::FormFieldText * > ( m_ff ) );
+        }
+    }
     return KTextEdit::event( e );
 }
 
@@ -687,6 +777,21 @@ void TextAreaEdit::slotChanged()
     Okular::FormFieldText *form = static_cast<Okular::FormFieldText *>(m_ff);
     QString contents = toPlainText();
     int cursorPos = textCursor().position();
+
+    if( form->additionalAction( Okular::FormField::FieldModified ) && m_editing && !form->isReadOnly() )
+    {
+        bool ok = false;
+        QString oldInputText = form->text();
+        form->setText( toPlainText() );
+        emit m_controller->keystrokeAction( form->additionalAction( Okular::FormField::FieldModified ), form, ok );
+        form->setText( oldInputText );
+        if(!ok)
+        {
+            setText( oldInputText );
+            return;
+        }
+    }
+
     if (contents != form->text())
     {
         m_controller->formTextChangedByWidget( pageItem()->pageNumber(),
@@ -1229,7 +1334,7 @@ void SignatureEdit::slotViewProperties()
         Okular::Action *act = m_ff->additionalAction( Okular::Annotation::FocusIn ); \
         if ( act ) \
         { \
-            m_controller->signalAction( act ); \
+            m_controller->processScriptAction( act, m_ff, Okular::Annotation::FocusIn ); \
         } \
         BaseClass::focusInEvent( event ); \
     } \
@@ -1238,7 +1343,7 @@ void SignatureEdit::slotViewProperties()
         Okular::Action *act = m_ff->additionalAction( Okular::Annotation::FocusOut ); \
         if ( act ) \
         { \
-            m_controller->signalAction( act ); \
+            m_controller->processScriptAction( act, m_ff, Okular::Annotation::FocusOut ); \
         } \
         BaseClass::focusOutEvent( event ); \
     } \
