@@ -383,7 +383,7 @@ void KTreeViewSearchLineWidget::createWidgets()
 
   QHBoxLayout* layout = new QHBoxLayout( this );
   layout->setSpacing( 5 );
-  layout->setMargin( 0 );
+  layout->setContentsMargins( 0, 0, 0, 0 );
   layout->addWidget( label );
   layout->addWidget( d->searchLine );
 }
