@@ -16,7 +16,6 @@
 #include "okularpart_export.h"
 
 class PageView;
-class QModelIndex;
 class QTreeView;
 class KTreeViewSearchLine;
 
@@ -35,7 +34,7 @@ Q_OBJECT
         ~Layers();
 
         // inherited from DocumentObserver
-        void notifySetup( const QVector< Okular::Page * > & pages, int setupFlags );
+        void notifySetup( const QVector< Okular::Page * > & pages, int setupFlags ) override;
 
         void setPageView( PageView *pageView );
 
