@@ -135,6 +135,7 @@ Q_OBJECT
         void mouseForwardButtonClick();
         void escPressed();
         void fitWindowToPage( const QSize& pageViewPortSize, const QSize& pageSize );
+        void triggerSearch( const QString& text );
 
     protected:
         bool event( QEvent * event ) override;
@@ -179,6 +180,8 @@ Q_OBJECT
         void updateZoom( ZoomMode newZm );
         // update the text on the label using global zoom value or current page's one
         void updateZoomText();
+        // update view mode (single, facing...)
+        void updateViewMode ( const int nr );
         void textSelectionClear();
         // updates cursor
         void updateCursor( const QPoint &p );
@@ -196,6 +199,7 @@ Q_OBJECT
         void resizeContentArea( const QSize & newSize );
         void updatePageStep();
 
+        void addSearchWithinDocumentAction(QMenu * menu, const QString & searchText );
         void addWebShortcutsMenu( QMenu * menu, const QString & text );
         QMenu* createProcessLinkMenu( PageViewItem *item, const QPoint & eventPos );
         // used when selecting stuff, makes the view scroll as necessary to keep the mouse inside the view
@@ -270,6 +274,7 @@ Q_OBJECT
         void slotSpeakDocument();
         void slotSpeakCurrentPage();
         void slotStopSpeaks();
+        void slotPauseResumeSpeech();
 #endif
         void slotAction( Okular::Action *action );
         void externalKeyPressEvent( QKeyEvent *e );
