@@ -205,7 +205,7 @@ bool PageViewItem::setFormWidgetsVisible( bool visible )
     for ( ; it != itEnd; ++it )
     {
         bool hadfocus = (*it)->setVisibility( visible && (*it)->formField()->isVisible() &&
-                                              !(*it)->formField()->isReadOnly() );
+                                              FormWidgetsController::shouldFormWidgetBeShown((*it)->formField()) );
         somehadfocus = somehadfocus || hadfocus;
     }
     return somehadfocus;
@@ -215,7 +215,7 @@ void PageViewItem::reloadFormWidgetsState()
 {
     foreach(FormWidgetIface *fwi, m_formWidgets)
     {
-        fwi->setVisibility( fwi->formField()->isVisible() && !fwi->formField()->isReadOnly() );
+        fwi->setVisibility( fwi->formField()->isVisible() && FormWidgetsController::shouldFormWidgetBeShown(fwi->formField()));
     }
 }
 
@@ -412,7 +412,7 @@ void PageViewMessage::paintEvent( QPaintEvent * /* e */ )
     const int textDrawingFlags = Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap;
 
     // draw shadow and text
-    painter.setPen( palette().color( QPalette::Window ).dark( 115 ) );
+    painter.setPen( palette().color( QPalette::Window ).darker( 115 ) );
     painter.drawText( xStartPoint + shadowOffset, yStartPoint + shadowOffset, textRect.width(), textRect.height(), textDrawingFlags, m_message );
     if ( !m_details.isEmpty() )
         painter.drawText( xStartPoint + shadowOffset, yStartPoint + textRect.height() + m_lineSpacing + shadowOffset, textRect.width(), detailsRect.height(), textDrawingFlags, m_details );
