@@ -469,7 +469,7 @@ Sidebar::Sidebar( QWidget *parent )
     : QWidget( parent ), d( new Private )
 {
     QHBoxLayout *mainlay = new QHBoxLayout( this );
-    mainlay->setMargin( 0 );
+    mainlay->setContentsMargins( 0, 0, 0, 0 );
     mainlay->setSpacing( 0 );
 
     setAutoFillBackground( true );
@@ -500,7 +500,7 @@ Sidebar::Sidebar( QWidget *parent )
     d->sideContainer->setMinimumWidth( 90 );
     d->sideContainer->setMaximumWidth( 600 );
     d->vlay = new QVBoxLayout( d->sideContainer );
-    d->vlay->setMargin( 0 );
+    d->vlay->setContentsMargins( 0, 0, 0, 0 );
 
     d->sideTitle = new QLabel( d->sideContainer );
     d->vlay->addWidget( d->sideTitle );
@@ -776,7 +776,7 @@ void Sidebar::listContextMenu( const QPoint &pos )
     const int itssize = static_cast< int >( _itssize ); \
     QAction *sizeAct = menu.addAction( text ); \
     sizeAct->setCheckable( true ); \
-    sizeAct->setData( qVariantFromValue( itssize ) ); \
+    sizeAct->setData( QVariant::fromValue( itssize ) ); \
     sizeAct->setChecked( itssize == curSize ); \
     sizeGroup->addAction( sizeAct ); \
 }
