@@ -22,12 +22,15 @@ class OkularTTS : public QObject
 
         void say( const QString &text );
         void stopAllSpeechs();
+        void pauseResumeSpeech();
 
     public slots:
         void slotSpeechStateChanged(QTextToSpeech::State state);
+        void slotConfigChanged();
 
     signals:
         void isSpeaking( bool speaking );
+        void canPauseOrResume( bool speakingOrPaused );
 
     private:
         // private storage
